﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using MyWebTest.Models;
using System.Net;
using System.IO;
using System.Data.Entity;

namespace MyWebTest.Controllers
{
    public class StudentsController : Controller
    {
        db_EducationEntities db = new db_EducationEntities();


        #region Index

        [HttpGet]
        public ActionResult Index()
        {
            var studentLisrt = db.T_Students;
            return View(studentLisrt);
        }

        #endregion

        #region Details

        [HttpGet]
        public ActionResult Details(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            var student = db.T_Students.Find(id);
            if (student == null)
            {
                return HttpNotFound();
            }
            return View(student);
        }

        #endregion

        #region Create

        [HttpGet]
        public ActionResult Create()
        {
            return View();
        }


        [HttpPost]
        public ActionResult Create([Bind(Include = "StudentName, StudentFamily, StudentAge, StudentPhoneNumber, StudentPassword, StudentEmail, StudentGender, StudentMarital")] T_Students student, HttpPostedFileBase imageUpload, string repeatPassword)
        {
            if (ModelState.IsValid)
            {
                if (student.StudentPassword != repeatPassword)
                {
                    ModelState.AddModelError("StudentPassword", "رمز عبور با تکرار آن مطابقت ندارد!");
                    return View(student);
                }

                string newImageName = "user.png";

                if (imageUpload != null)
                {
                    if (imageUpload.ContentType != "image/jpeg" && imageUpload.ContentType != "image/png")
                    {
                        ModelState.AddModelError("StudentImageName", "فرمت تصویر شما png یا jpg نیست!");
                        return View(student);
                    }

                    if (imageUpload.ContentLength > 500000)
                    {
                        ModelState.AddModelError("StudentImageName", "سایز تصویر شما بیشتر از 500 کیلوبایت است!");
                        return View(student);
                    }
                    newImageName = Guid.NewGuid().ToString().Replace("-", "") + Path.GetExtension(imageUpload.FileName);
                    imageUpload.SaveAs(Server.MapPath("/images/") + newImageName);
                }
                student.StudentImageName = newImageName;
                student.StudentRegisterDate = DateTime.Now;
                student.StudentIsActive = true;
                db.T_Students.Add(student);
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(student);
        }

        #endregion

        #region Edit

        [HttpGet]
        public ActionResult Edit(int? id)
        {
            if (id == null)
            {
                return new HttpStatusCodeResult(HttpStatusCode.BadRequest);
            }
            var student = db.T_Students.Find(id);
            if (student == null)
            {
                return HttpNotFound();
            }
            return View(student);
        }

        [HttpPost]
        public ActionResult Edit([Bind(Include = "StudentId, StudentName, StudentFamily, StudentAge, StudentPhoneNumber, StudentPassword, StudentEmail, StudentGender, StudentMarital, StudentImageName, StudentRegisterDate, StudentIsActive")] T_Students student, HttpPostedFileBase imageUpload)
        {
            if (ModelState.IsValid)
            {
                if (imageUpload != null)
                {
                    if (imageUpload.ContentType != "image/jpeg" && imageUpload.ContentType != "image/png")
                    {
                        ModelState.AddModelError("StudentImageName", "فرمت تصویر شما png یا jpg نیست!");
                        return View(student);
                    }

                    if (imageUpload.ContentLength > 500000)
                    {
                        ModelState.AddModelError("StudentImageName", "سایز تصویر شما بیشتر از 500 کیلوبایت است!");
                        return View(student);
                    }

                    string newImageName = Guid.NewGuid().ToString().Replace("-", "") + Path.GetExtension(imageUpload.FileName);
                    imageUpload.SaveAs(Server.MapPath("/images/") + newImageName);
                    student.StudentImageName = newImageName;
                }
                db.Entry(student).State = EntityState.Modified;
                db.SaveChanges();
                return RedirectToAction("Index");
            }
            return View(student);
        }

        #endregion





    }
}